# tszip
[![Tests](https://github.com/tskit-dev/tszip/actions/workflows/tests.yml/badge.svg)](https://github.com/tskit-dev/tszip/actions/workflows/tests.yml) [![CircleCI](https://circleci.com/gh/tskit-dev/tszip.svg?style=svg)](https://circleci.com/gh/tskit-dev/tszip) [![codecov](https://codecov.io/gh/tskit-dev/tszip/branch/main/graph/badge.svg)](https://codecov.io/gh/tskit-dev/tszip) [![Documentation Status](https://readthedocs.org/projects/tszip/badge/?version=latest)](https://tszip.readthedocs.io/en/latest/?badge=latest)

Gzip-like compression for [tskit](https://tskit.readthedocs.io/) tree sequences.

Please see the [documentation](https://tszip.readthedocs.io/) for more details
and [installation instructions](https://tszip.readthedocs.io/en/latest/installation.html).
